<h2> Some html and mermaid and mathjax markdown </h2>

\\( \int x dx = \frac{x^2}{2} + C \\)

When \\(a \ne 0\\), there are two solutions to \\(ax^2 + bx + c = 0\\) and they are
$$ x = {-b \pm \sqrt{b^2-4ac} \over 2a} $$

```mermaid
  graph TD;
      A-->B;
      A-->C;
      B-->D;
      C-->D;
```

```form-yaml
id: login_yaml
schema:
  user:
    type: text
    label: Username
```

```form-yaml
id: login_yaml
schema:
  user:
    type: text
    label: Username
```
  
```form-json
{
  "id": "login_json",
  "schema": {
    "user": {
      "type": "text",
      "label": "Username"
    }
  }
}
```

```form-json
{
  "id": "login_json",
  "schema": {
    "user": {
      "type": "text",
      "label": "Username"
    }
  }
}
```

